@@ -8,7 +8,7 @@ import json
 import time
 from networktools.ip import validURL
 from networktools.time import gps_time, now
-
+from rich import print
 
 async def run_test(loop, code, host, port, limit=2000, show=True):
     ginput = dict(host=host,
@@ -31,23 +31,20 @@ async def run_test(loop, code, host, port, limit=2000, show=True):
         gsof_file.write("[")
         while counter <= limit_counter:
             try:
-                print("Heart beat")
                 heartbeat = await gsof.heart_beat(idc)
-                print("Heartbeat", heartbeat)
                 if heartbeat:
-                    print("MSG recv>")
                     await gsof.get_message_header(idc)
-                    print("Header msg->", gsof.msg_bytes)
                     done, msg = await gsof.get_records()
                     ts = time.time()
                     if done:
                         if "TIME" in msg:
                             ts_gsof = gps_time(msg)
                             delta = ts - ts_gsof.timestamp()
+                            msg["DELTA_TIME"] = delta
                             print(f"Delta => {delta}")
                         if show:
                             print("Gsof %s" % code)
-                            [print(k, "->", v) for k, v in msg.items()]
+                            print(msg)
                         json.dump(msg, gsof_file, indent=2)
                         gsof_file.write(",\n")
                 else:
